%global optflags %(echo %{optflags} -Wl,--as-needed )

Name:       smb4k
Version:    1.2.3
Release:    1%{?dist}
Summary:    The SMB/CIFS Share Browser for KDE

Group:      Applications/Internet
License:    GPLv2+
URL:        http://smb4k.sourceforge.net/

Source0: http://downloads.sourceforge.net/smb4k/%{name}-%{version}.tar.xz

BuildRequires:  cmake >= 2.6.0
BuildRequires:  kdelibs4-devel >= 4.4.0
BuildRequires:  gettext
BuildRequires: desktop-file-utils
BuildRequires: libappstream-glib
Requires:   samba-client
Requires:   cifs-utils
Requires:   kdebase-runtime%{?_kde4_version: >= %{_kde4_version}}

# on F15 we need remove old smb4k-devel
Obsoletes: smb4k-devel < 1.0.0

# kde-plasma 4 only work with kde4 Fedora <= 21
%if 0%{?fedora} <= 21
#For now is just advertise kde-plasma-smb4k, maybe in future we should use Recommends:
Requires:   kde-plasma-smb4k%{?_isa} = %{version}-%{release}
%endif

# security fix CVE-2017-8849
Patch1:     smb4k-cve-2017-8849.patch

%description
Smb4K is an SMB/CIFS share browser for KDE. It uses the Samba software suite to
access the SMB/CIFS shares of the local network neighborhood. Its purpose is to
provide a program that's easy to use and has as many features as possible.

%package -n kde-plasma-smb4k
Summary: Plasma applet for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}
%description -n kde-plasma-smb4k
%{description}

%prep
%autosetup -p 1

%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
%{cmake_kde4} -Wno-dev ..
popd

make %{?_smp_mflags} -C %{_target_platform}

%install
make install DESTDIR=%{buildroot} -C %{_target_platform}
# delete devel .so
rm %{buildroot}%{_kde4_libdir}/libsmb4kcore.so

# add-category Network, because is Network application, search and map SMB/CIFS shares of LAN.
# add-category KDE, because is Application based on KDE libraries.
# add-category Utility, because is a small utility application.
desktop-file-install \
    --dir=%{buildroot}%{_kde4_datadir}/applications/kde4 \
    --add-category Network \
    --add-category KDE \
    --add-category Utility \
    --delete-original \
    %{buildroot}%{_kde4_datadir}/applications/kde4/smb4k.desktop

appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/appdata/*.appdata.xml

%find_lang %{name} --with-kde --all-name

%post
/sbin/ldconfig
/bin/touch --no-create %{_kde4_iconsdir}/hicolor &>/dev/null || :
/bin/touch --no-create %{_kde4_iconsdir}/oxygen &>/dev/null || :

%postun
/sbin/ldconfig
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_kde4_iconsdir}/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_kde4_iconsdir}/hicolor &>/dev/null || :
    /bin/touch --no-create %{_kde4_iconsdir}/oxygen &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_kde4_iconsdir}/oxygen &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_kde4_iconsdir}/hicolor &>/dev/null || :
/usr/bin/gtk-update-icon-cache %{_kde4_iconsdir}/oxygen &>/dev/null || :

%files -f %{name}.lang
%doc AUTHORS BUGS ChangeLog README
%license COPYING
%{_kde4_bindir}/*
%{_kde4_libdir}/kde4/smb4k*
%{_kde4_libdir}/libsmb4k*
%{_kde4_datadir}/applications/kde4/smb4k.desktop
%{_kde4_datadir}/config.kcfg/smb4k.kcfg
%{_kde4_iconsdir}/hicolor/*/apps/smb4k.png
%{_kde4_iconsdir}/oxygen/*/apps/smb4k.png
%{_kde4_appsdir}/kconf_update/*
%{_kde4_appsdir}/smb4k/
%{_kde4_libexecdir}/mounthelper
%{_sysconfdir}/dbus-1/system.d/net.sourceforge.smb4k.mounthelper.conf
%{_datadir}/dbus-1/system-services/net.sourceforge.smb4k.mounthelper.service
%{_datadir}/polkit-1/actions/net.sourceforge.smb4k.mounthelper.policy
%{_datadir}/appdata/smb4k.appdata.xml

%files -n kde-plasma-smb4k
%{_kde4_appsdir}/plasma/plasmoids/smb4k-qml
%{_datadir}/kde4/services/plasma-applet-smb4k-qml.desktop

%changelog
* Fri May 19 2017 Sérgio Basto <sergio@serjux.com> - 1.2.3-1
- Update smb4k to 1.2.3

* Wed May 10 2017 Than Ngo <than@redhat.com> - 1.2.2-3
- security fix for CVE-2017-8849

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Nov 30 2016 Sérgio Basto <sergio@serjux.com> - 1.2.2-1
- New upstream vesion, 1.2.2

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jan 20 2016 Sérgio Basto <sergio@serjux.com> - 1.2.1-2
- Only use update-desktop-database when a desktop entry has a MimeType key.
  http://fedoraproject.org/wiki/Packaging:ScriptletSnippets#desktop-database

* Fri Oct 16 2015 Sérgio Basto <sergio@serjux.com> - 1.2.1-1
- Update to 1.2.1

* Sun Jul 05 2015 Sérgio Basto <sergio@serjux.com> - 1.2.0-4
- Doesn't force installation of kde-plasma-smb4k in F22+ because only work with
  plasma 4 (F21) .

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jun 09 2015 Sérgio Basto <sergio@serjux.com> - 1.2.0-2
- Fix mixed-use-of-spaces-and-tabs.
- Fix desktop-file-install sriptlet.
- Fix license tag.
- Removed trailing spaces.
- Removed libsmb4kcore.so (devel-file) reverts fix of internal broken dependencies.
- Update smb4k.appdata.xml in smb4k-1.2.0_fixbuild.patch .
- Added a subpackage with kde-plasma-smb4k.
- Fixed unused-direct-shlib-dependency in cmake with global optflags.

* Sun Apr 19 2015 Sérgio Basto <sergio@serjux.com> - 1.2.0-1
- Update to 1.2.0
- Added AppData https://fedoraproject.org/wiki/Packaging:AppData
- Added patch to fix build already upstreamed.

* Mon Jan 05 2015 Sérgio Basto <sergio@serjux.com> - 1.1.4-1
- New bug fix release.

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat May 10 2014 Sérgio Basto <sergio@serjux.com> - 1.1.2-1
- New upstream release.

* Fri Mar 28 2014 Sérgio Basto <sergio@serjux.com> - 1.1.1-2
- Fix internal broken dependencies.

* Thu Mar 27 2014 Sérgio Basto <sergio@serjux.com> - 1.1.1-1
- Update to Smb4K 1.1.1, the first bug fix release of the stable 1.1 branch.
  This release fixes a crash bug and a potential security issue (rhbz #1079820)

* Sat Nov 09 2013 Sérgio Basto <sergio@serjux.com> - 1.0.9-1
- Update 1.0.9, bugfix release.

* Sat Oct 26 2013 Sérgio Basto <sergio@serjux.com> - 1.0.8-1
- Update to 1.0.8, bugfix release.
- Fix some dates.

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon May 13 2013 Sérgio Basto <sergio@serjux.com> - 1.0.7-1
- Update to 1.0.7, bugfix release.

* Sun Mar 10 2013 Sérgio Basto <sergio@serjux.com> - 1.0.6-1
- New upstream and bugfix release.

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Dec 27 2012 Sérgio Basto <sergio@serjux.com> - 1.0.5-1
- New upstream release.

* Wed Sep 26 2012 Sérgio Basto <sergio@serjux.com> - 1.0.4-1
- New upstream release.

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu May 31 2012 Sérgio Basto <sergio@serjux.com> 1.0.2
- New upstream release.

* Thu May 31 2012 Sérgio Basto <sergio@serjux.com> 1.0.1-8
- add patch to fix several bugs, from upcoming release 1.0.2.

* Mon May 07 2012 Sérgio Basto <sergio@serjux.com> 1.0.1-7
- add requires cifs-utils, to have mount.cifs

* Thu Apr 19 2012 Rex Dieter <rdieter@fedoraproject.org> 1.0.1-6
- remove some assumptions about qreal = double

* Tue Apr 10 2012 Sérgio Basto <sergio@serjux.com> - 1.0.1-5
- Obsoletes: smb4k-devel for F15.

* Mon Apr 2 2012 Sérgio Basto <sergio@serjux.com> - 1.0.1-4
- a little review.

* Wed Mar 28 2012 Sérgio Basto <sergio@serjux.com> - 1.0.1-3
- new review.

* Tue Mar 27 2012 Sérgio Basto <sergio@serjux.com> - 1.0.1-2
- review
- remove devel subpackage

* Sat Mar 24 2012 Sérgio Basto <sergio@serjux.com> - 1.0.1-1
- New upstream version 1.0.1
- some cleanups for fedora-review.

* Sun Dec 4 2011 Sérgio Basto <sergio@serjux.com> - 0.10.12-1
- update to 0.10.12
- drop qtstring upstreamed patch.

* Thu Dec 1 2011 Sérgio Basto <sergio@serjux.com> - 0.10.11-1
- update to 0.10.11
- patch a qtstring to fix a compile error.
- update homepage project and url source.

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Jun 21 2010 Marcin Garski <mgarski[AT]post.pl> 0.10.7-1
- Update to 0.10.7 (fix #574904)

* Wed Nov 25 2009 Kevin Kofler <Kevin@tigcc.ticalc.org> 0.10.4-2
- Rebuild for Qt 4.6.0 RC1 in F13 (was built against Beta 1 with unstable ABI)

* Sat Oct 24 2009 Marcin Garski <mgarski[AT]post.pl> 0.10.4-1
- Update to 0.10.4
- Proper update of sudoers (#527401)
- Add kdesu to Requires (#499720)

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun Mar 15 2009 Marcin Garski <mgarski[AT]post.pl> 0.10.2-1
- Update to 0.10.2

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Oct 18 2008 Marcin Garski <mgarski[AT]post.pl> 0.10.1-1
- Update to 0.10.1

* Thu Sep 04 2008 Marcin Garski <mgarski[AT]post.pl> 0.10.0-2
- Update to 0.10.0

* Wed Jul 30 2008 Marcin Garski <mgarski[AT]post.pl> 0.9.6-1
- Update to 0.9.6

* Mon Jun 02 2008 Marcin Garski <mgarski[AT]post.pl> 0.9.5-1
- Update to 0.9.5

* Tue Apr 29 2008 Marcin Garski <mgarski[AT]post.pl> 0.9.4-1
- Update to 0.9.4

* Sat Mar 01 2008 Marcin Garski <mgarski[AT]post.pl> 0.9.3-2
- Include .la files (bug #435149)

* Tue Feb 26 2008 Marcin Garski <mgarski[AT]post.pl> 0.9.3-1
- Update to 0.9.3

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.9.2-4
- Autorebuild for GCC 4.3

* Sat Jan 26 2008 Marcin Garski <mgarski[AT]post.pl> 0.9.2-3
- Update to 0.9.2
- Don't compile Konqueror plugin

* Sat Dec 08 2007 Marcin Garski <mgarski[AT]post.pl> 0.8.7-3
- Fix BR's to compile on rawhide

* Sun Dec 02 2007 Marcin Garski <mgarski[AT]post.pl> 0.8.7-2
- Add qt-devel to BR

* Sun Dec 02 2007 Marcin Garski <mgarski[AT]post.pl> 0.8.7-1
- Update to 0.8.7

* Sun Nov 11 2007 Marcin Garski <mgarski[AT]post.pl> 0.8.6-1
- Update to 0.8.6

* Thu Sep 27 2007 Marcin Garski <mgarski[AT]post.pl> 0.8.5-1
- Update to 0.8.5

* Fri Aug 31 2007 Marcin Garski <mgarski[AT]post.pl> 0.8.4-2
- Fix license tag

* Fri Aug 03 2007 Marcin Garski <mgarski[AT]post.pl> 0.8.4-1
- Update to 0.8.4
- Preserve upstream .desktop vendor

* Thu May 03 2007 Marcin Garski <mgarski[AT]post.pl> 0.8.3-1
- Updated to version 0.8.3

* Tue May 01 2007 Marcin Garski <mgarski[AT]post.pl> 0.8.2-1
- Updated to version 0.8.2
- Spec file cleanup

* Tue Apr 10 2007 Marcin Garski <mgarski[AT]post.pl> 0.8.1-1
- Updated to version 0.8.1

* Mon Jan 01 2007 Marcin Garski <mgarski[AT]post.pl> 0.8.0-1
- Updated to version 0.8.0

* Tue Nov 28 2006 Marcin Garski <mgarski[AT]post.pl> 0.7.5-1
- Updated to version 0.7.5

* Tue Nov 14 2006 Marcin Garski <mgarski[AT]post.pl> 0.7.4-1
- Updated to version 0.7.4

* Wed Sep 27 2006 Marcin Garski <mgarski[AT]post.pl> 0.7.3-1
- Updated to version 0.7.3

* Fri Sep 01 2006 Marcin Garski <mgarski[AT]post.pl> 0.7.2-2
- Rebuild for Fedora Core 6
- Spec tweak

* Fri Aug 18 2006 Marcin Garski <mgarski[AT]post.pl> 0.7.2-1
- Updated to version 0.7.2

* Mon Jun 19 2006 Marcin Garski <mgarski[AT]post.pl> 0.7.1-1
- Updated to version 0.7.1
- Drop smb4k-0.6.5-desktop.patch (merged upstream)

* Tue Apr 25 2006 Marcin Garski <mgarski[AT]post.pl> 0.7.0-1
- Updated to version 0.7.0, comment --enable-final

* Tue Apr 18 2006 Marcin Garski <mgarski[AT]post.pl> 0.6.10-1
- Updated to version 0.6.10

* Fri Mar 24 2006 Marcin Garski <mgarski[AT]post.pl> 0.6.9-1
- Updated to version 0.6.9

* Fri Feb 24 2006 Marcin Garski <mgarski[AT]post.pl> 0.6.8-1
- Updated to version 0.6.8

* Fri Feb 17 2006 Marcin Garski <mgarski[AT]post.pl> 0.6.7-4
- Updated smb4k-0.6.8-mount.patch

* Fri Feb 17 2006 Marcin Garski <mgarski[AT]post.pl> 0.6.7-3
- Add support of mount.cifs/umount.cifs (bug #181638)
- Remove smb4k-0.6.5-buff.patch

* Tue Feb 14 2006 Marcin Garski <mgarski[AT]post.pl> 0.6.7-2
- Rebuild

* Wed Feb 08 2006 Marcin Garski <mgarski[AT]post.pl> 0.6.7-1
- Updated to version 0.6.7

* Wed Feb 01 2006 Marcin Garski <mgarski[AT]post.pl> 0.6.5-5
- Fix GCC warnings
- Don't own KDE directories

* Wed Jan 18 2006 Marcin Garski <mgarski[AT]post.pl> 0.6.5-4
- Remove libxml2 from BR
- Add workaround for broken libtool archive (made by Dawid Gajownik)

* Sun Jan 15 2006 Marcin Garski <mgarski[AT]post.pl> 0.6.5-3
- Get rid of desktop-file-utils
- Add --disable-dependency-tracking & --enable-final

* Thu Jan 12 2006 Marcin Garski <mgarski[AT]post.pl> 0.6.5-2
- Add kdebase-devel to BuildRequires

* Wed Jan 11 2006 Marcin Garski <mgarski[AT]post.pl> 0.6.5-1
- Updated to version 0.6.5 && spec cleanup for FE

* Sun Sep 05 2004 Marcin Garski <mgarski[AT]post.pl> 0.4.1a-1.fc2
- Updated to version 0.4.1a

* Tue Aug 31 2004 Marcin Garski <mgarski[AT]post.pl> 0.4.1-1.fc2
- Updated to version 0.4.1

* Wed Jun 02 2004 Marcin Garski <mgarski[AT]post.pl> 0.4.0-3.fc2
- Rebuild for Fedora Core 2

* Thu May 06 2004 Marcin Garski <mgarski[AT]post.pl> 0.4.0-2
- Convert pl.po to UTF-8

* Thu May 06 2004 Marcin Garski <mgarski[AT]post.pl> 0.4.0-1
- Update to 0.4.0

* Wed Jan 21 2004 Marcin Garski <mgarski[AT]post.pl> 0.3.2-1
- Rebuild for Fedora Core 1

* Thu Dec 18 2003 Marcin Garski <mgarski[AT]post.pl> 0.3.1-3
- Cleanup specfile

* Fri Nov 28 2003 Marcin Garski <mgarski[AT]post.pl> 0.3.1-2
- Initial specfile based on specfile by Ian Geiser <geiseri[AT]msoe.edu>
